@@ -1,5 +1,4 @@
 from __future__ import unicode_literals
-import six
 import random
 import string
 
@@ -7,4 +6,4 @@ import string
 def create_id():
     size = 10
     chars = list(range(10)) + list(string.ascii_lowercase)
-    return "".join(six.text_type(random.choice(chars)) for x in range(size))
+    return "".join(str(random.choice(chars)) for x in range(size))
