@@ -230,11 +230,18 @@ class CloudFormationResponse(BaseResponse):
         stack = self.cloudformation_backend.get_stack(stack_name)
         logical_resource_id = self._get_param("LogicalResourceId")
 
+        resource = None
         for stack_resource in stack.stack_resources:
             if stack_resource.logical_resource_id == logical_resource_id:
                 resource = stack_resource
                 break
 
+        if not resource:
+            message = "Resource {0} does not exist for stack {1}".format(
+                logical_resource_id, stack_name
+            )
+            raise ValidationError(stack_name, message)
+
         template = self.response_template(DESCRIBE_STACK_RESOURCE_RESPONSE_TEMPLATE)
         return template.render(stack=stack, resource=resource)
 
