@@ -4,16 +4,28 @@ from werkzeug.exceptions import HTTPException
 from jinja2 import DictLoader, Environment
 import json
 
+# TODO: add "<Type>Sender</Type>" to error responses below?
+
 
 SINGLE_ERROR_RESPONSE = """<?xml version="1.0" encoding="UTF-8"?>
 <Error>
     <Code>{{error_type}}</Code>
     <Message>{{message}}</Message>
     {% block extra %}{% endblock %}
-    <RequestID>7a62c49f-347e-4fc4-9331-6e8eEXAMPLE</RequestID>
+    <{{request_id_tag}}>7a62c49f-347e-4fc4-9331-6e8eEXAMPLE</{{request_id_tag}}>
 </Error>
 """
 
+WRAPPED_SINGLE_ERROR_RESPONSE = """<?xml version="1.0" encoding="UTF-8"?>
+<ErrorResponse{% if xmlns is defined %} xmlns="{{xmlns}}"{% endif %}>
+    <Error>
+        <Code>{{error_type}}</Code>
+        <Message>{{message}}</Message>
+        {% block extra %}{% endblock %}
+        <{{request_id_tag}}>7a62c49f-347e-4fc4-9331-6e8eEXAMPLE</{{request_id_tag}}>
+    </Error>
+</ErrorResponse>"""
+
 ERROR_RESPONSE = """<?xml version="1.0" encoding="UTF-8"?>
   <ErrorResponse>
     <Errors>
@@ -23,7 +35,7 @@ ERROR_RESPONSE = """<?xml version="1.0" encoding="UTF-8"?>
         {% block extra %}{% endblock %}
       </Error>
     </Errors>
-  <RequestID>7a62c49f-347e-4fc4-9331-6e8eEXAMPLE</RequestID>
+  <{{request_id_tag}}>7a62c49f-347e-4fc4-9331-6e8eEXAMPLE</{{request_id_tag}}>
 </ErrorResponse>
 """
 
@@ -36,9 +48,12 @@ ERROR_JSON_RESPONSE = """{
 
 class RESTError(HTTPException):
     code = 400
+    # most APIs use <RequestId>, but some APIs (including EC2, S3) use <RequestID>
+    request_id_tag_name = "RequestId"
 
     templates = {
         "single_error": SINGLE_ERROR_RESPONSE,
+        "wrapped_single_error": WRAPPED_SINGLE_ERROR_RESPONSE,
         "error": ERROR_RESPONSE,
         "error_json": ERROR_JSON_RESPONSE,
     }
@@ -49,9 +64,23 @@ class RESTError(HTTPException):
         self.error_type = error_type
         self.message = message
         self.description = env.get_template(template).render(
-            error_type=error_type, message=message, **kwargs
+            error_type=error_type,
+            message=message,
+            request_id_tag=self.request_id_tag_name,
+            **kwargs
         )
 
+        self.content_type = "application/xml"
+
+    def get_headers(self, *args, **kwargs):
+        return [
+            ("X-Amzn-ErrorType", self.error_type or "UnknownError"),
+            ("Content-Type", self.content_type),
+        ]
+
+    def get_body(self, *args, **kwargs):
+        return self.description
+
 
 class DryRunClientError(RESTError):
     code = 400
@@ -60,9 +89,7 @@ class DryRunClientError(RESTError):
 class JsonRESTError(RESTError):
     def __init__(self, error_type, message, template="error_json", **kwargs):
         super(JsonRESTError, self).__init__(error_type, message, template, **kwargs)
-
-    def get_headers(self, *args, **kwargs):
-        return [("Content-Type", "application/json")]
+        self.content_type = "application/json"
 
     def get_body(self, *args, **kwargs):
         return self.description
