@@ -1,6 +1,6 @@
 from moto.dynamodb2.comparisons import get_comparison_func
-from moto.dynamodb2.exceptions import InvalidUpdateExpression, IncorrectDataType
-from moto.dynamodb2.models.utilities import attribute_is_list, bytesize
+from moto.dynamodb2.exceptions import IncorrectDataType
+from moto.dynamodb2.models.utilities import bytesize
 
 
 class DDBType(object):
@@ -36,14 +36,7 @@ class DDBTypeConversion(object):
         Returns:
             str: The human readable form of the DDBType.
         """
-        try:
-            human_type_str = cls._human_type_mapping[abbreviated_type]
-        except KeyError:
-            raise ValueError(
-                "Invalid abbreviated_type {at}".format(at=abbreviated_type)
-            )
-
-        return human_type_str
+        return cls._human_type_mapping.get(abbreviated_type, abbreviated_type)
 
 
 class DynamoType(object):
@@ -63,70 +56,6 @@ class DynamoType(object):
         elif self.is_map():
             self.value = dict((k, DynamoType(v)) for k, v in self.value.items())
 
-    def get(self, key):
-        if not key:
-            return self
-        else:
-            key_head = key.split(".")[0]
-            key_tail = ".".join(key.split(".")[1:])
-            if key_head not in self.value:
-                self.value[key_head] = DynamoType({"NONE": None})
-            return self.value[key_head].get(key_tail)
-
-    def set(self, key, new_value, index=None):
-        if index:
-            index = int(index)
-            if type(self.value) is not list:
-                raise InvalidUpdateExpression
-            if index >= len(self.value):
-                self.value.append(new_value)
-            # {'L': [DynamoType, ..]} ==> DynamoType.set()
-            self.value[min(index, len(self.value) - 1)].set(key, new_value)
-        else:
-            attr = (key or "").split(".").pop(0)
-            attr, list_index = attribute_is_list(attr)
-            if not key:
-                # {'S': value} ==> {'S': new_value}
-                self.type = new_value.type
-                self.value = new_value.value
-            else:
-                if attr not in self.value:  # nonexistingattribute
-                    type_of_new_attr = DDBType.MAP if "." in key else new_value.type
-                    self.value[attr] = DynamoType({type_of_new_attr: {}})
-                # {'M': {'foo': DynamoType}} ==> DynamoType.set(new_value)
-                self.value[attr].set(
-                    ".".join(key.split(".")[1:]), new_value, list_index
-                )
-
-    def __contains__(self, item):
-        if self.type == DDBType.STRING:
-            return False
-        try:
-            self.__getitem__(item)
-            return True
-        except KeyError:
-            return False
-
-    def delete(self, key, index=None):
-        if index:
-            if not key:
-                if int(index) < len(self.value):
-                    del self.value[int(index)]
-            elif "." in key:
-                self.value[int(index)].delete(".".join(key.split(".")[1:]))
-            else:
-                self.value[int(index)].delete(key)
-        else:
-            attr = key.split(".")[0]
-            attr, list_index = attribute_is_list(attr)
-
-            if list_index:
-                self.value[attr].delete(".".join(key.split(".")[1:]), list_index)
-            elif "." in key:
-                self.value[attr].delete(".".join(key.split(".")[1:]))
-            else:
-                self.value.pop(key)
-
     def filter(self, projection_expressions):
         nested_projections = [
             expr[0 : expr.index(".")] for expr in projection_expressions if "." in expr
