@@ -1,6 +1,6 @@
 from __future__ import unicode_literals
 from moto.core.responses import BaseResponse
-from moto.ec2.utils import filters_from_querystring
+from moto.ec2.utils import filters_from_querystring, add_tag_specification
 
 
 class TransitGatewayAttachment(BaseResponse):
@@ -88,6 +88,16 @@ class TransitGatewayAttachment(BaseResponse):
         template = self.response_template(TRANSIT_GATEWAY_ASSOCIATION)
         return template.render(transit_gateway_association=transit_gateway_association)
 
+    def disassociate_transit_gateway_route_table(self,):
+        tgw_attach_id = self._get_param("TransitGatewayAttachmentId")
+        tgw_rt_id = self._get_param("TransitGatewayRouteTableId")
+
+        tgw_association = self.ec2_backend.disassociate_transit_gateway_route_table(
+            tgw_attach_id, tgw_rt_id
+        )
+        template = self.response_template(TRANSIT_GATEWAY_DISASSOCIATION)
+        return template.render(tgw_association=tgw_association)
+
     def enable_transit_gateway_route_table_propagation(self):
         transit_gateway_attachment_id = self._get_param("TransitGatewayAttachmentId")
         transit_gateway_route_table_id = self._get_param("TransitGatewayRouteTableId")
@@ -108,6 +118,74 @@ class TransitGatewayAttachment(BaseResponse):
         template = self.response_template(TRANSIT_GATEWAY_PROPAGATION)
         return template.render(transit_gateway_propagation=transit_gateway_propagation)
 
+    def create_transit_gateway_peering_attachment(self):
+        peer_account_id = self._get_param("PeerAccountId")
+        peer_region = self._get_param("PeerRegion")
+        peer_transit_gateway_id = self._get_param("PeerTransitGatewayId")
+        transit_gateway_id = self._get_param("TransitGatewayId")
+        tags = add_tag_specification(self._get_multi_param("TagSpecification"))
+        transit_gateway_peering_attachment = self.ec2_backend.create_transit_gateway_peering_attachment(
+            transit_gateway_id,
+            peer_transit_gateway_id,
+            peer_region,
+            peer_account_id,
+            tags,
+        )
+        template = self.response_template(TRANSIT_GATEWAY_PEERING_ATTACHMENT)
+        return template.render(
+            method_name="CreateTransitGatewayPeeringAttachment",
+            transit_gateway_peering_attachment=transit_gateway_peering_attachment,
+        )
+
+    def describe_transit_gateway_peering_attachments(self):
+        transit_gateways_attachment_ids = self._get_multi_param(
+            "TransitGatewayAttachmentIds"
+        )
+        filters = filters_from_querystring(self.querystring)
+        max_results = self._get_param("MaxResults")
+        transit_gateway_peering_attachments = self.ec2_backend.describe_transit_gateway_peering_attachments(
+            transit_gateways_attachment_ids=transit_gateways_attachment_ids,
+            filters=filters,
+            max_results=max_results,
+        )
+        template = self.response_template(DESCRIBE_TRANSIT_GATEWAY_PEERING_ATTACHMENTS)
+        return template.render(
+            transit_gateway_peering_attachments=transit_gateway_peering_attachments
+        )
+
+    def accept_transit_gateway_peering_attachment(self):
+        transit_gateway_attachment_id = self._get_param("TransitGatewayAttachmentId")
+        transit_gateway_peering_attachment = self.ec2_backend.accept_transit_gateway_peering_attachment(
+            transit_gateway_attachment_id=transit_gateway_attachment_id
+        )
+        template = self.response_template(TRANSIT_GATEWAY_PEERING_ATTACHMENT)
+        return template.render(
+            method_name="AcceptTransitGatewayPeeringAttachment",
+            transit_gateway_peering_attachment=transit_gateway_peering_attachment,
+        )
+
+    def delete_transit_gateway_peering_attachment(self):
+        transit_gateway_attachment_id = self._get_param("TransitGatewayAttachmentId")
+        transit_gateway_peering_attachment = self.ec2_backend.delete_transit_gateway_peering_attachment(
+            transit_gateway_attachment_id=transit_gateway_attachment_id
+        )
+        template = self.response_template(TRANSIT_GATEWAY_PEERING_ATTACHMENT)
+        return template.render(
+            method_name="DeleteTransitGatewayPeeringAttachment",
+            transit_gateway_peering_attachment=transit_gateway_peering_attachment,
+        )
+
+    def reject_transit_gateway_peering_attachment(self):
+        transit_gateway_attachment_id = self._get_param("TransitGatewayAttachmentId")
+        transit_gateway_peering_attachment = self.ec2_backend.reject_transit_gateway_peering_attachment(
+            transit_gateway_attachment_id=transit_gateway_attachment_id
+        )
+        template = self.response_template(TRANSIT_GATEWAY_PEERING_ATTACHMENT)
+        return template.render(
+            method_name="RejectTransitGatewayPeeringAttachment",
+            transit_gateway_peering_attachment=transit_gateway_peering_attachment,
+        )
+
 
 CREATE_TRANSIT_GATEWAY_VPC_ATTACHMENT = """<CreateTransitGatewayVpcAttachmentResponse xmlns="http://ec2.amazonaws.com/doc/2016-11-15/">
         <requestId>9b5766ac-2af6-4b92-9a8a-4d74ae46ae79</requestId>
@@ -283,6 +361,19 @@ TRANSIT_GATEWAY_ASSOCIATION = """<AssociateTransitGatewayRouteTableResponse xmln
 """
 
 
+TRANSIT_GATEWAY_DISASSOCIATION = """<DisassociateTransitGatewayRouteTableResponse xmlns="http://ec2.amazonaws.com/doc/2016-11-15/">
+    <requestId>86a597cf-93ec-44a3-9559-4641863642a5</requestId>
+    <association>
+        <resourceId>{{ tgw_association.resource_id }}</resourceId>
+        <resourceType>{{ tgw_association.resource_type }}</resourceType>
+        <state>{{ tgw_association.state }}</state>
+        <transitGatewayAttachmentId>{{ tgw_association.transit_gateway_attachment_id }}</transitGatewayAttachmentId>
+        <transitGatewayRouteTableId>{{ tgw_association.transit_gateway_route_table_id }}</transitGatewayRouteTableId>
+    </association>
+</DisassociateTransitGatewayRouteTableResponse>
+"""
+
+
 TRANSIT_GATEWAY_PROPAGATION = """<EnableTransitGatewayRouteTablePropagationResponse xmlns="http://ec2.amazonaws.com/doc/2016-11-15/">
     <requestId>c78427d4-e498-46ae-bc14-32841b16bff4</requestId>
     <propagation>
@@ -294,3 +385,66 @@ TRANSIT_GATEWAY_PROPAGATION = """<EnableTransitGatewayRouteTablePropagationRespo
     </propagation>
 </EnableTransitGatewayRouteTablePropagationResponse>
 """
+
+
+TRANSIT_GATEWAY_PEERING_ATTACHMENT = """<{{ method_name }} xmlns="http://ec2.amazonaws.com/doc/2016-11-15/">
+        <requestId>9b5766ac-2af6-4b92-9a8a-4d74ae46ae79</requestId>
+        <transitGatewayPeeringAttachment>
+            <createTime>{{ transit_gateway_peering_attachment.create_time }}</createTime>
+            <state>{{ transit_gateway_peering_attachment.state }}</state>
+            <accepterTgwInfo>
+                <ownerId>{{ transit_gateway_peering_attachment.accepter_tgw_info.ownerId or '' }}</ownerId>
+                <region>{{ transit_gateway_peering_attachment.accepter_tgw_info.region or '' }}</region>
+                <transitGatewayId>{{ transit_gateway_peering_attachment.accepter_tgw_info.transitGatewayId or '' }}</transitGatewayId>
+            </accepterTgwInfo>
+            <requesterTgwInfo>
+                <ownerId>{{ transit_gateway_peering_attachment.requester_tgw_info.ownerId or '' }}</ownerId>
+                <region>{{ transit_gateway_peering_attachment.requester_tgw_info.region or '' }}</region>
+                <transitGatewayId>{{ transit_gateway_peering_attachment.requester_tgw_info.transitGatewayId or '' }}</transitGatewayId>
+            </requesterTgwInfo>
+            <status>{{ transit_gateway_peering_attachment.status.code }}</status>
+            <tagSet>
+            {% for tag in transit_gateway_peering_attachment.get_tags() %}
+                <item>
+                    <key>{{ tag.key }}</key>
+                    <value>{{ tag.value }}</value>
+                </item>
+            {% endfor %}
+            </tagSet>
+            <transitGatewayAttachmentId>{{ transit_gateway_peering_attachment.id }}</transitGatewayAttachmentId>
+    </transitGatewayPeeringAttachment>
+</{{ method_name }}>"""
+
+
+DESCRIBE_TRANSIT_GATEWAY_PEERING_ATTACHMENTS = """<DescribeTransitGatewayPeeringAttachments xmlns="http://ec2.amazonaws.com/doc/2016-11-15/">
+        <requestId>bebc9670-0205-4f28-ad89-049c97e46633</requestId>
+        <transitGatewayPeeringAttachments>
+        {% for transit_gateway_peering_attachment in transit_gateway_peering_attachments %}
+            <item>
+                <createTime>{{ transit_gateway_peering_attachment.create_time }}</createTime>
+                <state>{{ transit_gateway_peering_attachment.state }}</state>
+                <accepterTgwInfo>
+                    <ownerId>{{ transit_gateway_peering_attachment.accepter_tgw_info.ownerId or '' }}</ownerId>
+                    <region>{{ transit_gateway_peering_attachment.accepter_tgw_info.region or '' }}</region>
+                    <transitGatewayId>{{ transit_gateway_peering_attachment.accepter_tgw_info.transitGatewayId or '' }}</transitGatewayId>
+                </accepterTgwInfo>
+                <requesterTgwInfo>
+                    <ownerId>{{ transit_gateway_peering_attachment.requester_tgw_info.ownerId or '' }}</ownerId>
+                    <region>{{ transit_gateway_peering_attachment.requester_tgw_info.region or '' }}</region>
+                    <transitGatewayId>{{ transit_gateway_peering_attachment.requester_tgw_info.transitGatewayId or '' }}</transitGatewayId>
+                </requesterTgwInfo>
+                <status>{{ transit_gateway_peering_attachment.status.code }}</status>
+                <tagSet>
+                {% for tag in transit_gateway_peering_attachment.get_tags() %}
+                    <item>
+                        <key>{{ tag.key }}</key>
+                        <value>{{ tag.value }}</value>
+                    </item>
+                {% endfor %}
+                </tagSet>
+                <transitGatewayAttachmentId>{{ transit_gateway_peering_attachment.id }}</transitGatewayAttachmentId>
+            </item>
+        {% endfor %}
+    </transitGatewayPeeringAttachments>
+</DescribeTransitGatewayPeeringAttachments>
+"""
