@@ -13,7 +13,18 @@ class VirtualPrivateGateways(BaseResponse):
 
     def create_vpn_gateway(self):
         type = self._get_param("Type")
-        vpn_gateway = self.ec2_backend.create_vpn_gateway(type)
+        amazon_side_asn = self._get_param("AmazonSideAsn")
+        availability_zone = self._get_param("AvailabilityZone")
+        tags = self._get_multi_param("TagSpecification")
+        tags = tags[0] if isinstance(tags, list) and len(tags) == 1 else tags
+        tags = (tags or {}).get("Tag", [])
+        tags = {t["Key"]: t["Value"] for t in tags}
+        vpn_gateway = self.ec2_backend.create_vpn_gateway(
+            type=type,
+            amazon_side_asn=amazon_side_asn,
+            availability_zone=availability_zone,
+            tags=tags,
+        )
         template = self.response_template(CREATE_VPN_GATEWAY_RESPONSE)
         return template.render(vpn_gateway=vpn_gateway)
 
@@ -44,7 +55,7 @@ CREATE_VPN_GATEWAY_RESPONSE = """
     <vpnGatewayId>{{ vpn_gateway.id }}</vpnGatewayId>
     <state>available</state>
     <type>{{ vpn_gateway.type }}</type>
-    <availabilityZone>us-east-1a</availabilityZone>
+    <availabilityZone>{{ vpn_gateway.availability_zone }}</availabilityZone>
     <attachments/>
     <tagSet>
       {% for tag in vpn_gateway.get_tags() %}
