@@ -15,4 +15,6 @@ url_paths = {
     "{0}/clusters/(?P<name>[^/]+)$": response.dispatch,
     "{0}/clusters/(?P<name>[^/]+)/node-groups$": response.dispatch,
     "{0}/clusters/(?P<name>[^/]+)/node-groups/(?P<nodegroupName>[^/]+)$": response.dispatch,
+    "{0}/clusters/(?P<name>[^/]+)/fargate-profiles$": response.dispatch,
+    "{0}/clusters/(?P<name>[^/]+)/fargate-profiles/(?P<fargateProfileName>[^/]+)$": response.dispatch,
 }
