@@ -2,6 +2,7 @@ from __future__ import unicode_literals
 
 import json
 from werkzeug.exceptions import BadRequest
+from moto.core import ACCOUNT_ID
 
 
 class ResourceNotFoundError(BadRequest):
@@ -23,14 +24,14 @@ class ResourceInUseError(BadRequest):
 class StreamNotFoundError(ResourceNotFoundError):
     def __init__(self, stream_name):
         super(StreamNotFoundError, self).__init__(
-            "Stream {0} under account 123456789012 not found.".format(stream_name)
+            "Stream {0} under account {1} not found.".format(stream_name, ACCOUNT_ID)
         )
 
 
 class ShardNotFoundError(ResourceNotFoundError):
     def __init__(self, shard_id):
         super(ShardNotFoundError, self).__init__(
-            "Shard {0} under account 123456789012 not found.".format(shard_id)
+            "Shard {0} under account {1} not found.".format(shard_id, ACCOUNT_ID)
         )
 
 
