@@ -10,7 +10,7 @@ from hashlib import md5
 
 from boto3 import Session
 
-from moto.compat import OrderedDict
+from collections import OrderedDict
 from moto.core import BaseBackend, BaseModel, CloudFormationModel
 from moto.core.utils import unix_time
 from moto.core import ACCOUNT_ID
@@ -350,6 +350,8 @@ class DeliveryStream(BaseModel):
             "redshift_s3_buffering_hints"
         )
 
+        self.elasticsearch_config = stream_kwargs.get("elasticsearch_config")
+
         self.records = []
         self.status = "ACTIVE"
         self.created_at = datetime.datetime.utcnow()
@@ -373,6 +375,31 @@ class DeliveryStream(BaseModel):
                     "ExtendedS3DestinationDescription": self.extended_s3_config,
                 }
             ]
+        elif self.elasticsearch_config:
+            return [
+                {
+                    "DestinationId": "string",
+                    "ElasticsearchDestinationDescription": {
+                        "RoleARN": self.elasticsearch_config.get("RoleARN"),
+                        "DomainARN": self.elasticsearch_config.get("DomainARN"),
+                        "ClusterEndpoint": self.elasticsearch_config.get(
+                            "ClusterEndpoint"
+                        ),
+                        "IndexName": self.elasticsearch_config.get("IndexName"),
+                        "TypeName": self.elasticsearch_config.get("TypeName"),
+                        "IndexRotationPeriod": self.elasticsearch_config.get(
+                            "IndexRotationPeriod"
+                        ),
+                        "BufferingHints": self.elasticsearch_config.get(
+                            "BufferingHints"
+                        ),
+                        "RetryOptions": self.elasticsearch_config.get("RetryOptions"),
+                        "S3DestinationDescription": self.elasticsearch_config.get(
+                            "S3Configuration"
+                        ),
+                    },
+                }
+            ]
         else:
             return [
                 {
