@@ -9,7 +9,7 @@ class LogsClientError(JsonRESTError):
 class ResourceNotFoundException(LogsClientError):
     def __init__(self, msg=None):
         self.code = 400
-        super(ResourceNotFoundException, self).__init__(
+        super().__init__(
             "ResourceNotFoundException", msg or "The specified log group does not exist"
         )
 
@@ -17,7 +17,7 @@ class ResourceNotFoundException(LogsClientError):
 class InvalidParameterException(LogsClientError):
     def __init__(self, msg=None):
         self.code = 400
-        super(InvalidParameterException, self).__init__(
+        super().__init__(
             "InvalidParameterException", msg or "A parameter is specified incorrectly."
         )
 
@@ -25,7 +25,7 @@ class InvalidParameterException(LogsClientError):
 class ResourceAlreadyExistsException(LogsClientError):
     def __init__(self):
         self.code = 400
-        super(ResourceAlreadyExistsException, self).__init__(
+        super().__init__(
             "ResourceAlreadyExistsException", "The specified log group already exists"
         )
 
@@ -33,6 +33,4 @@ class ResourceAlreadyExistsException(LogsClientError):
 class LimitExceededException(LogsClientError):
     def __init__(self):
         self.code = 400
-        super(LimitExceededException, self).__init__(
-            "LimitExceededException", "Resource limit exceeded."
-        )
+        super().__init__("LimitExceededException", "Resource limit exceeded.")
