@@ -1,20 +1,23 @@
+import uuid
+
 from boto3 import Session
 
 from moto import core as moto_core
 from moto.core import BaseBackend, BaseModel
 from moto.core.utils import unix_time_millis
-from .exceptions import (
+from moto.logs.exceptions import (
     ResourceNotFoundException,
     ResourceAlreadyExistsException,
     InvalidParameterException,
     LimitExceededException,
 )
-import uuid
+
+MAX_RESOURCE_POLICIES_PER_REGION = 10
 
 
 class LogQuery(BaseModel):
-    def __init__(self, id, start_time, end_time, query):
-        self.id = id
+    def __init__(self, query_id, start_time, end_time, query):
+        self.query_id = query_id
         self.start_time = start_time
         self.end_time = end_time
         self.query = query
@@ -24,16 +27,16 @@ class LogEvent(BaseModel):
     _event_id = 0
 
     def __init__(self, ingestion_time, log_event):
-        self.ingestionTime = ingestion_time
+        self.ingestion_time = ingestion_time
         self.timestamp = log_event["timestamp"]
         self.message = log_event["message"]
-        self.eventId = self.__class__._event_id
+        self.event_id = self.__class__._event_id
         self.__class__._event_id += 1
 
     def to_filter_dict(self):
         return {
-            "eventId": str(self.eventId),
-            "ingestionTime": self.ingestionTime,
+            "eventId": str(self.event_id),
+            "ingestionTime": self.ingestion_time,
             # "logStreamName":
             "message": self.message,
             "timestamp": self.timestamp,
@@ -41,7 +44,7 @@ class LogEvent(BaseModel):
 
     def to_response_dict(self):
         return {
-            "ingestionTime": self.ingestionTime,
+            "ingestionTime": self.ingestion_time,
             "message": self.message,
             "timestamp": self.timestamp,
         }
@@ -58,13 +61,13 @@ class LogStream(BaseModel):
             log_group=log_group,
             log_stream=name,
         )
-        self.creationTime = int(unix_time_millis())
-        self.firstEventTimestamp = None
-        self.lastEventTimestamp = None
-        self.lastIngestionTime = None
-        self.logStreamName = name
-        self.storedBytes = 0
-        self.uploadSequenceToken = (
+        self.creation_time = int(unix_time_millis())
+        self.first_event_timestamp = None
+        self.last_event_timestamp = None
+        self.last_ingestion_time = None
+        self.log_stream_name = name
+        self.stored_bytes = 0
+        self.upload_sequence_token = (
             0  # I'm  guessing this is token needed for sequenceToken by put_events
         )
         self.events = []
@@ -75,10 +78,10 @@ class LogStream(BaseModel):
 
     def _update(self):
         # events can be empty when stream is described soon after creation
-        self.firstEventTimestamp = (
+        self.first_event_timestamp = (
             min([x.timestamp for x in self.events]) if self.events else None
         )
-        self.lastEventTimestamp = (
+        self.last_event_timestamp = (
             max([x.timestamp for x in self.events]) if self.events else None
         )
 
@@ -88,16 +91,16 @@ class LogStream(BaseModel):
 
         res = {
             "arn": self.arn,
-            "creationTime": self.creationTime,
-            "logStreamName": self.logStreamName,
-            "storedBytes": self.storedBytes,
+            "creationTime": self.creation_time,
+            "logStreamName": self.log_stream_name,
+            "storedBytes": self.stored_bytes,
         }
         if self.events:
             rest = {
-                "firstEventTimestamp": self.firstEventTimestamp,
-                "lastEventTimestamp": self.lastEventTimestamp,
-                "lastIngestionTime": self.lastIngestionTime,
-                "uploadSequenceToken": str(self.uploadSequenceToken),
+                "firstEventTimestamp": self.first_event_timestamp,
+                "lastEventTimestamp": self.last_event_timestamp,
+                "lastIngestionTime": self.last_ingestion_time,
+                "uploadSequenceToken": str(self.upload_sequence_token),
             }
             res.update(rest)
         return res
@@ -107,21 +110,23 @@ class LogStream(BaseModel):
     ):
         # TODO: ensure sequence_token
         # TODO: to be thread safe this would need a lock
-        self.lastIngestionTime = int(unix_time_millis())
+        self.last_ingestion_time = int(unix_time_millis())
         # TODO: make this match AWS if possible
-        self.storedBytes += sum([len(log_event["message"]) for log_event in log_events])
+        self.stored_bytes += sum(
+            [len(log_event["message"]) for log_event in log_events]
+        )
         events = [
-            LogEvent(self.lastIngestionTime, log_event) for log_event in log_events
+            LogEvent(self.last_ingestion_time, log_event) for log_event in log_events
         ]
         self.events += events
-        self.uploadSequenceToken += 1
+        self.upload_sequence_token += 1
 
         if self.destination_arn and self.destination_arn.split(":")[2] == "lambda":
             from moto.awslambda import lambda_backends  # due to circular dependency
 
             lambda_log_events = [
                 {
-                    "id": event.eventId,
+                    "id": event.event_id,
                     "timestamp": event.timestamp,
                     "message": event.message,
                 }
@@ -136,7 +141,7 @@ class LogStream(BaseModel):
                 lambda_log_events,
             )
 
-        return "{:056d}".format(self.uploadSequenceToken)
+        return "{:056d}".format(self.upload_sequence_token)
 
     def get_log_events(
         self,
@@ -243,7 +248,7 @@ class LogStream(BaseModel):
             filter(filter_func, self.events), key=lambda x: x.timestamp
         ):
             event_obj = event.to_filter_dict()
-            event_obj["logStreamName"] = self.logStreamName
+            event_obj["logStreamName"] = self.log_stream_name
             events.append(event_obj)
         return events
 
@@ -252,10 +257,8 @@ class LogGroup(BaseModel):
     def __init__(self, region, name, tags, **kwargs):
         self.name = name
         self.region = region
-        self.arn = "arn:aws:logs:{region}:1:log-group:{log_group}".format(
-            region=region, log_group=name
-        )
-        self.creationTime = int(unix_time_millis())
+        self.arn = f"arn:aws:logs:{region}:{moto_core.ACCOUNT_ID}:log-group:{name}"
+        self.creation_time = int(unix_time_millis())
         self.tags = tags
         self.streams = dict()  # {name: LogStream}
         self.retention_in_days = kwargs.get(
@@ -289,7 +292,7 @@ class LogGroup(BaseModel):
         next_token,
         order_by,
     ):
-        # responses only logStreamName, creationTime, arn, storedBytes when no events are stored.
+        # responses only log_stream_name, creation_time, arn, stored_bytes when no events are stored.
 
         log_streams = [
             (name, stream.to_describe_dict())
@@ -432,7 +435,7 @@ class LogGroup(BaseModel):
             )
 
         searched_streams = [
-            {"logStreamName": stream.logStreamName, "searchedCompletely": True}
+            {"logStreamName": stream.log_stream_name, "searchedCompletely": True}
             for stream in streams
         ]
         return events_page, next_token, searched_streams
@@ -440,10 +443,10 @@ class LogGroup(BaseModel):
     def to_describe_dict(self):
         log_group = {
             "arn": self.arn,
-            "creationTime": self.creationTime,
+            "creationTime": self.creation_time,
             "logGroupName": self.name,
             "metricFilterCount": 0,
-            "storedBytes": sum(s.storedBytes for s in self.streams.values()),
+            "storedBytes": sum(s.stored_bytes for s in self.streams.values()),
         }
         # AWS only returns retentionInDays if a value is set for the log group (ie. not Never Expire)
         if self.retention_in_days:
@@ -483,7 +486,7 @@ class LogGroup(BaseModel):
             if self.subscription_filters[0]["filterName"] == filter_name:
                 creation_time = self.subscription_filters[0]["creationTime"]
             else:
-                raise LimitExceededException
+                raise LimitExceededException()
 
         for stream in self.streams.values():
             stream.destination_arn = destination_arn
@@ -686,9 +689,49 @@ class LogsBackend(BaseBackend):
         log_group = self.groups[log_group_name]
         return log_group.set_retention_policy(None)
 
+    def describe_resource_policies(
+        self, next_token, limit
+    ):  # pylint: disable=unused-argument
+        """Return list of resource policies.
+
+        The next_token and limit arguments are ignored.  The maximum
+        number of resource policies per region is a small number (less
+        than 50), so pagination isn't needed.
+        """
+        limit = limit or MAX_RESOURCE_POLICIES_PER_REGION
+
+        policies = []
+        for policy_name, policy_info in self.resource_policies.items():
+            policies.append(
+                {
+                    "policyName": policy_name,
+                    "policyDocument": policy_info["policyDocument"],
+                    "lastUpdatedTime": policy_info["lastUpdatedTime"],
+                }
+            )
+        return policies
+
     def put_resource_policy(self, policy_name, policy_doc):
-        policy = {"policyName": policy_name, "policyDocument": policy_doc}
+        """Create resource policy and return dict of policy name and doc."""
+        if len(self.resource_policies) == MAX_RESOURCE_POLICIES_PER_REGION:
+            raise LimitExceededException()
+
+        policy = {
+            "policyName": policy_name,
+            "policyDocument": policy_doc,
+            "lastUpdatedTime": int(unix_time_millis()),
+        }
         self.resource_policies[policy_name] = policy
+        return {"resourcePolicy": policy}
+
+    def delete_resource_policy(self, policy_name):
+        """Remove resource policy with a policy name matching given name."""
+        if policy_name not in self.resource_policies:
+            raise ResourceNotFoundException(
+                msg=f"Policy with name [{policy_name}] does not exist"
+            )
+        del self.resource_policies[policy_name]
+        return ""
 
     def list_tags_log_group(self, log_group_name):
         if log_group_name not in self.groups:
@@ -760,9 +803,13 @@ class LogsBackend(BaseBackend):
 
 
 logs_backends = {}
-for region in Session().get_available_regions("logs"):
-    logs_backends[region] = LogsBackend(region)
-for region in Session().get_available_regions("logs", partition_name="aws-us-gov"):
-    logs_backends[region] = LogsBackend(region)
-for region in Session().get_available_regions("logs", partition_name="aws-cn"):
-    logs_backends[region] = LogsBackend(region)
+for available_region in Session().get_available_regions("logs"):
+    logs_backends[available_region] = LogsBackend(available_region)
+for available_region in Session().get_available_regions(
+    "logs", partition_name="aws-us-gov"
+):
+    logs_backends[available_region] = LogsBackend(available_region)
+for available_region in Session().get_available_regions(
+    "logs", partition_name="aws-cn"
+):
+    logs_backends[available_region] = LogsBackend(available_region)
