@@ -1,4 +1,5 @@
 from __future__ import unicode_literals
+
 from moto.core.exceptions import JsonRESTError
 
 
@@ -6,6 +7,15 @@ class MediaStoreClientError(JsonRESTError):
     code = 400
 
 
+class ContainerNotFoundException(MediaStoreClientError):
+    def __init__(self, msg=None):
+        self.code = 400
+        super(ContainerNotFoundException, self).__init__(
+            "ContainerNotFoundException",
+            msg or "The specified container does not exist",
+        )
+
+
 class ResourceNotFoundException(MediaStoreClientError):
     def __init__(self, msg=None):
         self.code = 400
