@@ -32,6 +32,7 @@ class FakeOrganization(BaseModel):
         self.master_account_id = utils.MASTER_ACCOUNT_ID
         self.master_account_email = utils.MASTER_ACCOUNT_EMAIL
         self.available_policy_types = [
+            # TODO: verify if this should be enabled by default (breaks TF tests for CloudTrail)
             {"Type": "SERVICE_CONTROL_POLICY", "Status": "ENABLED"}
         ]
 
@@ -141,7 +142,10 @@ class FakeRoot(FakeOrganizationalUnit):
         self.type = "ROOT"
         self.id = organization.root_id
         self.name = "Root"
-        self.policy_types = [{"Type": "SERVICE_CONTROL_POLICY", "Status": "ENABLED"}]
+        self.policy_types = [
+            # TODO: verify if this should be enabled by default (breaks TF tests for CloudTrail)
+            {"Type": "SERVICE_CONTROL_POLICY", "Status": "ENABLED"}
+        ]
         self._arn_format = utils.ROOT_ARN_FORMAT
         self.attached_policies = []
         self.tags = {tag["Key"]: tag["Value"] for tag in kwargs.get("Tags", [])}
@@ -328,6 +332,9 @@ class FakeDelegatedAdministrator(BaseModel):
 
 class OrganizationsBackend(BaseBackend):
     def __init__(self):
+        self._reset()
+
+    def _reset(self):
         self.org = None
         self.accounts = []
         self.ou = []
@@ -375,6 +382,10 @@ class OrganizationsBackend(BaseBackend):
             raise AWSOrganizationsNotInUseException
         return self.org.describe()
 
+    def delete_organization(self, **kwargs):
+        self._reset()
+        return {}
+
     def list_roots(self):
         return dict(Roots=[ou.describe() for ou in self.ou if isinstance(ou, FakeRoot)])
 
