@@ -2,8 +2,7 @@ from __future__ import unicode_literals
 import logging
 
 import re
-import six
-from six.moves.urllib.parse import urlparse, unquote, quote
+from urllib.parse import urlparse, unquote, quote
 from requests.structures import CaseInsensitiveDict
 import sys
 from moto.settings import S3_IGNORE_SUBDOMAIN_BUCKETNAME
@@ -75,7 +74,7 @@ def metadata_from_headers(headers):
     metadata = CaseInsensitiveDict()
     meta_regex = re.compile(r"^x-amz-meta-([a-zA-Z0-9\-_.]+)$", flags=re.IGNORECASE)
     for header, value in headers.items():
-        if isinstance(header, six.string_types):
+        if isinstance(header, str):
             result = meta_regex.match(header)
             meta_key = None
             if result:
@@ -94,14 +93,10 @@ def metadata_from_headers(headers):
 
 
 def clean_key_name(key_name):
-    if six.PY2:
-        return unquote(key_name.encode("utf-8")).decode("utf-8")
     return unquote(key_name)
 
 
 def undo_clean_key_name(key_name):
-    if six.PY2:
-        return quote(key_name.encode("utf-8")).decode("utf-8")
     return quote(key_name)
 
 
@@ -149,23 +144,28 @@ class _VersionedKeyStore(dict):
         super(_VersionedKeyStore, self).__setitem__(key, list_)
 
     def _iteritems(self):
-        for key in self:
+        for key in self._self_iterable():
             yield key, self[key]
 
     def _itervalues(self):
-        for key in self:
+        for key in self._self_iterable():
             yield self[key]
 
     def _iterlists(self):
-        for key in self:
+        for key in self._self_iterable():
             yield key, self.getlist(key)
 
     def item_size(self):
         size = 0
-        for val in self.values():
+        for val in self._self_iterable().values():
             size += sys.getsizeof(val)
         return size
 
+    def _self_iterable(self):
+        # to enable concurrency, return a copy, to avoid "dictionary changed size during iteration"
+        # TODO: look into replacing with a locking mechanism, potentially
+        return dict(self)
+
     items = iteritems = _iteritems
     lists = iterlists = _iterlists
     values = itervalues = _itervalues
