@@ -1,5 +1,4 @@
 import json
-import six
 
 from moto.core.responses import BaseResponse
 
@@ -31,7 +30,7 @@ class SWFResponse(BaseResponse):
             self._check_string(parameter)
 
     def _check_string(self, parameter):
-        if not isinstance(parameter, six.string_types):
+        if not isinstance(parameter, str):
             raise SWFSerializationException(parameter)
 
     def _check_none_or_list_of_strings(self, parameter):
@@ -42,7 +41,7 @@ class SWFResponse(BaseResponse):
         if not isinstance(parameter, list):
             raise SWFSerializationException(parameter)
         for i in parameter:
-            if not isinstance(i, six.string_types):
+            if not isinstance(i, str):
                 raise SWFSerializationException(parameter)
 
     def _check_exclusivity(self, **kwargs):
